@@ -1,11 +1,15 @@
 package Hailo::Tokenizer::Words;
 use 5.010;
 use utf8;
-use Moose;
-use MooseX::StrictConstructor;
+use Any::Moose;
+BEGIN {
+    return unless Any::Moose::moose_is_preferred();
+    require MooseX::StrictConstructor;
+    MooseX::StrictConstructor->import;
+}
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 with qw(Hailo::Role::Arguments
         Hailo::Role::Tokenizer);
@@ -23,6 +27,7 @@ my $CLOSE_QUOTE = qr/['"’“”«»」』›‘]/;
 my $TERMINATOR  = qr/(?:[?!‽]+|(?<!\.)\.)/;
 my $ADDRESS     = qr/:/;
 my $PUNCTUATION = qr/[?!‽,;.:]/;
+my $WORD_SPLIT  = qr{[-/](?![-/])};
 my $BOUNDARY    = qr/\s*$CLOSE_QUOTE?\s*(?:$TERMINATOR|$ADDRESS)\s+$OPEN_QUOTE?\s*/;
 
 # we want to capitalize words that come after "On example.com?"
@@ -85,7 +90,7 @@ sub make_output {
     }
 
     # capitalize the first word
-    $reply =~ s/^$TERMINATOR?\s*$OPEN_QUOTE?\s*\K($WORD)(?=(?:$TERMINATOR+|$ADDRESS|$PUNCTUATION+)?(?:-| |$))/\u$1/;
+    $reply =~ s/^$TERMINATOR?\s*$OPEN_QUOTE?\s*\K($WORD)(?=(?:$TERMINATOR+|$ADDRESS|$PUNCTUATION+)?(?:$WORD_SPLIT| |$))/\u$1/;
 
     # capitalize the second word
     $reply =~ s/^$TERMINATOR?\s*$OPEN_QUOTE?\s*$WORD(?:\s*(?:$TERMINATOR|$ADDRESS)\s+)\K($WORD)/\u$1/;
@@ -97,7 +102,7 @@ sub make_output {
     $reply =~ s/\x1B//g;
 
     # end paragraphs with a period when it makes sense
-    $reply =~ s/(?:-| |^)$OPEN_QUOTE?$WORD$CLOSE_QUOTE?\K$/./;
+    $reply =~ s/(?:$WORD_SPLIT| |^)$OPEN_QUOTE?$WORD$CLOSE_QUOTE?\K$/./;
 
     # capitalize I
     $reply =~ s{ \Ki(?=$PUNCTUATION| |$APOSTROPHE)}{I}g;
