@@ -1,7 +1,7 @@
 package Hailo::Test;
 use 5.010;
 use autodie;
-use Moose;
+use Any::Moose;
 use Hailo;
 use Test::More;
 use File::Spec::Functions qw(catfile);
@@ -124,7 +124,14 @@ sub spawn_storage {
     );
 
     if (exists $classes{$storage}) {
-        eval { Class::MOP::load_class($classes{$storage}) };
+        my $pkg = $classes{$storage};
+        if (Any::Moose::moose_is_preferred()) {
+            require Class::MOP;
+            eval { Class::MOP::load_class($pkg) };
+        } else {
+            eval qq[require $pkg];
+        }
+
         return if $@;
     }
 
